function [ wHat, proxParam ] = proxLinfClip( b, y, A, proxParam, prior )

%   Input:
%       b: estimation
%       y: initial input signal
%       A: function handle to the frequency transform dictionnary/analysis
%          operator
%       proxParam: parameter structure with epsilon field
%       prior: (string) 'analysis' or 'synthesis'
%
%   Output:
%       wHat: estimated signal projected on the declipping (magnitude) constraint
%       proxParam: updated parameter structure
%
%		References:
%				[1] Kitić, S., Bertin, N., & Gribonval, R. Sparsity and cosparsity for audio declipping:
%				a flexible non-convex approach. In International Conference on Latent Variable Analysis
%				and Signal Separation (pp. 243-250). Springer, Cham.
%				[2] Záviška, P., Rajmic, P., Průša, Z., & Veselý, V. Revisiting synthesis model in sparse
%				audio declipper. In International Conference on Latent Variable Analysis
%				and Signal Separation (pp. 429-445). Springer, Cham.
%
% ************************************************************
% This software is available under the  BSD-3-Clause License  (https://opensource.org/licenses/BSD-3-Clause)
% ************************************************************
% 3-Clause BSD License
% 
% Copyright <2016-2019><INRIA - CNRS><Clément Gaultier, Srdan Kitic, Ewen Camberlein, Rémi Gribonval, Nancy Bertin>
% 
% Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
% 
% (i) Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
% 
% (ii) Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
% 
% (iii) Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
% 
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
%
% Contact: nancy.bertin@irisa.fr, frederic.bimbot@irisa.fr, remi.gribonval@inria.fr
% PANAMA Research Group,  IRISA  -  (Inria & CNRS)
% Campus de Beaulieu, 35042 Rennes cedex, France


if strcmpi(prior,'analysis')

    wHat = A(b,'transp');

    viol_pos = (proxParam.clip_pos & wHat < y);
    viol_neg = (proxParam.clip_neg & wHat > y);

    wHat(viol_pos(:)) = y(viol_pos(:));
    wHat(viol_neg(:)) = y(viol_neg(:));
    wHat(proxParam.rel_ind(:)) = y(proxParam.rel_ind(:));

else

    b_time = A(b,'transp');
    wtemp_time =  b_time;

    viol_pos = (proxParam.clip_pos & b_time < y);
    viol_neg = (proxParam.clip_neg & b_time > y);

    wtemp_time(viol_pos(:)) = y(viol_pos(:));
    wtemp_time(viol_neg(:)) = y(viol_neg(:));
    wtemp_time(proxParam.rel_ind(:)) = y(proxParam.rel_ind(:));

    wHat = b - A(b_time - wtemp_time,'notransp');

end
end
