function [ param ] = checkAndInitGlobalParams( param )
%% checkAndInitGlobalParams initialize the param structure
% initializes fields in param with the default values for the audio
% reconstruction experiments
%
% ************************************************************
% This software is available under the  BSD-3-Clause License  (https://opensource.org/licenses/BSD-3-Clause)
% ************************************************************
% 3-Clause BSD License
% 
% Copyright <2016-2019><INRIA - CNRS><Clément Gaultier, Srdan Kitic, Ewen Camberlein, Rémi Gribonval, Nancy Bertin>
% 
% Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
% 
% (i) Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
% 
% (ii) Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
% 
% (iii) Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
% 
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
% 
% Contact: nancy.bertin@irisa.fr, frederic.bimbot@irisa.fr, remi.gribonval@inria.fr
% PANAMA Research Group,  IRISA  -  (Inria & CNRS)
% Campus de Beaulieu, 35042 Rennes cedex, France   

if ~isfield(param, 'Pb') || isempty(param.Pb)
    param.Pb = 'Denoising';
end

if ~isfield(param, 'iSNR') || isempty(param.iSNR)
    param.iSNR = 10;
end

if ~isfield(param, 'prior') || isempty(param.prior)
    param.prior = 'analysis';
end

if ~isfield(param, 'Shrinkage') || isempty(param.Shrinkage)
    param.Shrinkage = 'PEW';
end

if ~isfield(param, 'loud') || isempty(param.loud)
    param.loud = false;
end

if ~isfield(param, 'Fs') || isempty(param.Fs)
    param.Fs = 16000;
end

if ~isfield(param, 'w_size') || isempty(param.w_size)
    param.w_size = pow2(nextpow2(0.064*Fs));
end

if ~isfield(param, 'window') || isempty(param.window)
    param.window = @hamming;
end

if ~isfield(param, 'overlap') || isempty(param.overlap)
    param.overlap = 0.75;
end

if ~isfield(param, 'stepsize') || isempty(param.stepsize)
    param.stepsize = param.w_size*(1-param.overlap);
end

if ~isfield(param, 'redundancy') || isempty(param.redundancy)
    param.redundancy = 1;
end

if ~isfield(param, 'accuracy') || isempty(param.accuracy)
    param.accuracy = 0.1;
end

if ~isfield(param, 'causal') || isempty(param.causal)
    param.causal = false;
end

if ~isfield(param, 'transform') || isempty(param.transform)
    param.transform = 'DFT';
end

switch upper(param.prior)
    case 'ANALYSIS'
        prior = 'Cosparse';
    case 'SYNTHESIS'
        prior = 'Sparse';
    otherwise
        error('Unknown modeling prior!')
end

switch upper(param.Pb)
    case 'DENOISING'
        tool = 'Denoiser';
    case 'DECLIPPING'
        tool = 'Declipper';
    otherwise
        error('Unknown audio reconstruction application!')
end

switch upper(param.Shrinkage)
    case 'HT'
        model = 'Plain';
    case 'PEW'
        model = 'Social';
    otherwise
        error('Unknown sparsity model!')
end

expMessage = ['Running ' model ' ' prior ' ' tool '...'];

warningMessage = ['To abort type ctrl+c or press cancel in loud mode.'];



disp('-----------------')
disp(expMessage)
disp(warningMessage)



end

