%% Run audio restoration demo (declipping or denoising)
%
%   Runs the signal restoration (denoising or declipping) for 
%   all the audio files in the 'CleanAudioData' folder and for 
%   all the tested SDR / SNR conditions in the vector SDRs
%
% ************************************************************
% This software is available under the  BSD-3-Clause License  (https://opensource.org/licenses/BSD-3-Clause)
% ************************************************************
% 3-Clause BSD License
% 
% Copyright <2016-2019><INRIA - CNRS><Clément Gaultier, Srdan Kitic, Ewen Camberlein, Rémi Gribonval, Nancy Bertin>
% 
% Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
% 
% (i) Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
% 
% (ii) Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
% 
% (iii) Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
% 
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
% 
% Contact: nancy.bertin@irisa.fr, frederic.bimbot@irisa.fr, remi.gribonval@inria.fr
% PANAMA Research Group,  IRISA  -  (Inria & CNRS)
% Campus de Beaulieu, 35042 Rennes cedex, France
%
%

fileLIST = dir('./../../CleanAudioData/*.wav'); % List of the clean sound files
SDRs = [0;1;3;5;10;15;20;25;30];                    % List of the input SDR / SNR to be tested

for f = 1:length(fileLIST)
    for s = 1:length(SDRs)

% Setting path
oldPath = path;
addpath('./../Core/')

% Setting parameters
CleanFile = fileLIST(f).name;   % Clean filename
SDR = SDRs(s);                  % Tested SDR / SNR
param.Pb = 'Declipping';        % Reconstruction problem (Denoising / Declipping)

% Basic algorithm parameters
param.window_length = 0.064;    % Window length in seconds (64 ms for music, 32 for speech)
param.prior = 'analysis';       % analysis or synthesis modeling prior
param.Shrinkage = 'HT';         % shrinkage used for the sparsifying step
                                % (HT: Hard Thresholding or PEW: Persistent Empirical Wiener)
param.transform = 'DFT';        % Frequency transform used for analysis operator / dictionary (DFT or DCT)
param.accuracy = 1e-3;          % Convergence threshold for the algorithm
param.redundancy = 2;           % Redundancy of the frequency transform
param.loud = 1;                 % waitbar on/off

% Processing
runAudioRestorationExperiment(CleanFile, SDR, param)

% Restoring path
path(oldPath);
    end
end
