function sig_out = setLeveldBFS(sig,desired_level_dBFS)
%% setLeveldBFS set the input signal to the desired level in dB (full scale ref=1)
%   
%   Input:
%       sig: input signal
%       desired_level_dBFS: target level in dB (dBFS as ref is 1)
%
%   Output:
%       sig_out: output signal scaled to the target level
%
% ************************************************************
% This software is available under the  BSD-3-Clause License  (https://opensource.org/licenses/BSD-3-Clause)
% ************************************************************
% 3-Clause BSD License
% 
% Copyright <2016-2019><INRIA - CNRS><Clément Gaultier, Srdan Kitic, Ewen Camberlein, Rémi Gribonval, Nancy Bertin>
% 
% Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
% 
% (i) Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
% 
% (ii) Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
% 
% (iii) Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
% 
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
% 
% Contact: nancy.bertin@irisa.fr, frederic.bimbot@irisa.fr, remi.gribonval@inria.fr
% PANAMA Research Group,  IRISA  -  (Inria & CNRS)
% Campus de Beaulieu, 35042 Rennes cedex, France
%

% ref signal rms power
level_sig_rms = sqrt(mean(sig.^2));
% ref signal level (dBFS)
level_sig_dBFS=20*log10(level_sig_rms);

% scale to desired level
sig_out=sig*10^((desired_level_dBFS - level_sig_dBFS)/20);

end