function [ y_padd , y_indexes] = performZeroPadding( y, windowSize, hopSize, timeBlocks )
%% zeroPadding performs simple zero padding on y given the window size
%
%   Input:
%       y: input signal to padd 
%       windowSize: size of the window in samples (int)
%       hopSize: size of the overlap jump in samples (int)
%       timeBlocks: number of time blocks to consider in case of
%                   block-processing
%
%   Output: 
%       y_padd: padded signal
%       y_indexes: indexes of the initial y in y_padd
%
% ************************************************************
% This software is available under the  BSD-3-Clause License  (https://opensource.org/licenses/BSD-3-Clause)
% ************************************************************
% 3-Clause BSD License
% 
% Copyright <2016-2019><INRIA - CNRS><Clément Gaultier, Srdan Kitic, Ewen Camberlein, Rémi Gribonval, Nancy Bertin>
% 
% Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
% 
% (i) Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
% 
% (ii) Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
% 
% (iii) Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
% 
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
% 
% Contact: nancy.bertin@irisa.fr, frederic.bimbot@irisa.fr, remi.gribonval@inria.fr
% PANAMA Research Group,  IRISA  -  (Inria & CNRS)
% Campus de Beaulieu, 35042 Rennes cedex, France
%
%

if nargin < 4
    timeBlocks = 0; %basic frame processing (otherwise block processing)
end
blockSize = 2*timeBlocks*hopSize + windowSize;
[a,b] = size(y); 
N = max(a,b); % length
Dimy = min(a,b); %chanels

NbFrames = floor((N-blockSize)/hopSize + 1); % int nb of frame split
NbEndSample = N - ((NbFrames-1)*hopSize + blockSize); % remaining samples


PrePaddNb = blockSize/2; % zero padding at the beginning 
PostPaddNb = blockSize - NbEndSample; % zero padding at the end


if a > b % column vector
    y_padd = [zeros(PrePaddNb,Dimy);y;zeros(PostPaddNb,Dimy)];
else % line vector
    y_padd = [zeros(Dimy,PrePaddNb) y zeros(Dimy,PostPaddNb)];

end

y_indexes = [PrePaddNb+1 length(y_padd)-PostPaddNb]; % indexes of the original signal y


end

